@@ -3,7 +3,7 @@ import i18next from '../src/i18next.js';
 const instance = i18next.createInstance();
 
 describe('i18next.interpolation.nesting', () => {
-  before(done => {
+  before((done) => {
     instance.init(
       {
         lng: 'en',
@@ -93,7 +93,7 @@ describe('i18next.interpolation.nesting', () => {
       },
     ];
 
-    tests.forEach(test => {
+    tests.forEach((test) => {
       it('correctly nests for ' + JSON.stringify(test.args) + ' args', () => {
         expect(instance.t.apply(instance, test.args)).to.eql(test.expected);
       });
